local L = LibStub("AceLocale-3.0"):GetLocale("DirectionArrow", false)

-- Config options
DirectionArrowConfig = { 
  type='group',
  name = L["DirectionArrow"],
  desc = L["Display an arrow that points to a raid/party member"],
  args = {
    General = {
      order = 1,
      type = "group",
      name = L["General Options"],
      desc = L["General Options"],
      args = {
        size = {
          order = 1,
          type = 'range',
          name = L["Size"],
          desc = L["The size of the arrow"],
          get = function ()
            return DirectionArrow.db.profile.size
          end,
          set = function (i, arg)
            DirectionArrow.db.profile.size = arg
            DirectionArrow.f:SetScale (arg)
          end,
          min = 1,
          max = 5,
          step = 0.1,
        },
        relative_location = {
          order = 2,
          type = 'select',
          name = L["Arrow Location"],
          desc = L["The relative location of the arrow against the unit frame."],
          get = function ()
            return DirectionArrow.db.profile.relative_location
          end,
          set = function (i, arg)
            DirectionArrow.db.profile.relative_location = arg
          end,
          values = {
            TOPLEFT = L["Top Left"],
            TOP = L["Top"],
            TOPRIGHT = L["Top Right"],
            LEFT = L["Left"],
            CENTER = L["Center"],
            RIGHT = L["Right"],
            BOTTOMLEFT = L["Bottom Left"],
            BOTTOM = L["Bottom"],
            BOTTOMRIGHT = L["Bottom Right"],
          },
        },
        spacer11 = {
          order = 3,
          type = "description",
          name = "",
        },
        opacity = {
          order = 4,
          type = 'range',
          name = L["Opacity"],
          desc = L["The opacity of the arrow"],
          get = function ()
            return DirectionArrow.db.profile.opacity
          end,
          set = function (i, arg)
            DirectionArrow.db.profile.opacity = arg
            DirectionArrow.f:SetAlpha (arg)
          end,
          min = 0,
          max = 1,
          step = 0.05,
        },
        update_frequency = {
          order = 5,
          type = 'range',
          name = L["Update Frequency"],
          desc = L["The number of cycles between each arrow update. 0 means every cycle (Possibly CPU intensive)"],
          get = function ()
            return DirectionArrow.db.profile.update_frequency
          end,
          set = function (i, arg)
            DirectionArrow.db.profile.update_frequency = arg
          end,
          min = 0,
          max = 1,
          step = 0.05,
        },
        spacer12 = {
          order = 6,
          type = "description",
          name = "",
        },
      }
    }
  }
}

-- Config defaults
DirectionArrowDefaultConfigDB = {
  global = {
    ["*"] = {},
  },
  profile = {
    size = 1,
    opacity = 1,
    relative_location = "CENTER",
    update_frequency = 0,
  }
}
